#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_CEIL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_CEIL_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/ceil.hpp>

#endif
